@@ -53,6 +53,9 @@ void defaults()
 	safecopy(state.hourcolor, "#ef3838", 50);
 	safecopy(state.daycolor, "#a0a0a0", 50);
 	safecopy(state.datecolor, "#a0a0a0", 50);
+	state.run_program = 0;
+	safecopy(state.program_name, 
+			"echo astime: No program specified.", 255);
 }
 
 /* print the usage for the tool */
@@ -62,6 +65,7 @@ void usage()
         printf("-V              print version and exit\n");
         printf("-h -H -help     print this message\n");
         printf("-u <secs>       the update interval in seconds\n");
+	printf("-exe <prog>	the program to start when clicked on\n");
         printf("-nosec		don't draw the second pointer\n");
         printf("-nodate		don't show the date/day of the week\n");
         printf("-noampm		don't show the AM/PM indicator\n");
@@ -86,7 +90,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("astime : AfterStep analogue clock version 1.6\n");
+        printf("astime : AfterStep analogue clock version 1.7\n");
 }               
 
 void    parsecmdline(int argc, char *argv[])
@@ -162,6 +166,11 @@ void    parsecmdline(int argc, char *argv[])
 				if (++i >= argc)
 					usage();
 				safecopy(state.datecolor, argv[i], 50);
+			} else if (!strncmp(argument,"-exe",4)) {
+				if (++i >= argc)
+					usage();
+				safecopy(state.program_name, argv[i], 255);
+				state.run_program = 1;
                         } else if (!strncmp(argument,"-V",2)) { 
                                 version();
                                 exit(0);
