@@ -358,6 +358,9 @@ void CheckX11Events()
 				++update_request;
 			}
                         break;
+		case ButtonPress:
+			system(state.program_name);
+			break;
                 case ClientMessage:
                         if ((Event.xclient.message_type == wm_protocols)
                           && (Event.xclient.data.l[0] == wm_delete_window))
@@ -797,11 +800,22 @@ void initialize(
         XStoreName(mainDisplay, mainWindow, window_name);
         XSetIconName(mainDisplay, mainWindow, window_name);
 
-        status = XSelectInput(
-                mainDisplay,    /* display */
-                mainWindow,     /* window */
-                ExposureMask    /* event_mask */
-                );
+	/*
+	 * If the user did not specify a program to run
+	 * we do not intercept mouse clicks in our window.
+	 */
+	if ( state.run_program )
+		status = XSelectInput(
+			mainDisplay,			/* display */
+			mainWindow,			/* window */
+			ExposureMask|ButtonPressMask	/* event_mask */
+			);
+	else
+		status = XSelectInput(
+			mainDisplay,			/* display */
+			mainWindow,			/* window */
+			ExposureMask			/* event_mask */
+			);
                 
         status = XSelectInput(
                 mainDisplay,    /* display */
