@@ -13,6 +13,7 @@ struct astime_state {
 	unsigned short int draw_ampm;
 	struct coordinates total_size;
 	short int shift;
+	unsigned short int run_program;
 	char bgcolor[50];
 	char fgcolor[50];
 	char seccolor[50];
@@ -20,6 +21,7 @@ struct astime_state {
 	char hourcolor[50];
 	char daycolor[50];
 	char datecolor[50];
+	char program_name[255];
 };
 
 #endif
